#
# spec file for package python-dropbox
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-dropbox
Version:        10.4.1
Release:        3.2
Summary:        Official Dropbox API Client
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/dropbox/dropbox-sdk-python
Source:         https://files.pythonhosted.org/packages/source/d/dropbox/dropbox-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.16.2}
BuildRequires:  %{python_module six >= 1.3.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-requests >= 2.16.2
Requires:       python-six >= 1.3.0
BuildArch:      noarch

%python_subpackages

%description
Official Dropbox API Client

%prep
%setup -q -n dropbox-%{version}
# https://github.com/dropbox/dropbox-sdk-python/issues/401
sed -i 's:pytest-runner::' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Tests require an access token

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Tue Apr 23 2024 Georg Pfuetzenreuter <mail+rpm@georg-pfuetzenreuter.net>
- Switch to sle15_python_module_pythons to build for newer Python stack
* Thu Dec  9 2021 pgajdos@suse.com
- do not require pytest-runner for build, not required
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 10.4.1:
  * Fix bug with client copy
  * Fix bug with team client as_user and as_admin
  * Fix Python 3 linter issue
  * Update tox.ini to check python 3.7 and 3.8
  * Update setup.py to support python 3.7 and 3.8
  * Remove stone as submodule and add as dependency
  * Update Spec
  * Files Namespace
  * Add internal_error to SearchError union.
  * Add locked to LookupError union.
  * Add cant_move_into_vault to RelocationError union.
  * Add MoveIntoVaultError union.
  * Add SearchMatchFieldOptions struct.
  * Add optional match_field_options to SearchV2Arg struct.
  * Doc/example changes.
  * Sharing Namespace
  * Add is_vault to SharePathError union.
  * Add invalid_shared_folder to AddFolderMemberError union.
  * Team Namespace
  * Make members field of LegalHoldsPolicyUpdateArg struct optional.
  * Add app_folder_removal_not_supported to RevokeLinkedAppError union.
  * Doc/example changes.
  * Add auto_approve to InviteMethod union.
  * Add moved_from_another_team to InviteMethod union.
  * Add moved_from_another_team to MemberStatus union.
  * Add no_one to SharedLinkVisibility union.
  * Add optional new_team to MemberChangeStatusDetails struct.
  * Add optional previous_team to MemberChangeStatusDetails struct.
  * Add external_sharing_create_report_details to EventDetails union.
  * Add external_sharing_report_failed to EventDetails union.
  * Add content_administration_policy_changed_details to EventDetails
  * Add external_sharing_create_report to EventType.
  * Add external_sharing_report_failed to EventType.
  * Add content_administration_policy_changed to EventType.
  * union.
  * Add send_for_signature_policy_changed_details to EventDetails union.
  * Add external_sharing_create_report to EventTypeArgs union.
  * Add external_sharing_report_failed to EventTypeArgs union.
  * Add content_administration_policy_changed to EventTypeArgs union.
  * Add send_for_signature_policy_changed to EventTypeArgs union.
  * Add SendForSignaturePolicy union.
  * Add ExternalSharingCreateReportDetails struct.
  * Add ExternalSharingReportFailedDetails struct.
  * Add ContentAdministrationPolicyChangedDetails struct.
  * Add SendForSignaturePolicyChangedDetails struct.
  * Add ExternalSharingCreateReportType struct.
  * Add ExternalSharingReportFailedType struct.
  * Add ContentAdministrationPolicyChangedType struct.
  * Add SendForSignaturePolicyChangedType struct.
* Tue Jun 16 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 10.2.0:
  * Added comments to legalHoldPolicy struct
  * Add more detailed comments to LegalHoldsListHeldRevisionResult
  * Fix misc typos in comments
  * Add optional EventTypeArg event_type to GetTeamEventsArg struct
  * Add invalid_filters to GetTeamEventsError union
  * Add deprecated tag to was_linked_apps_truncated, was_linked_devices_truncated, was_link_shared_folders_truncated parameters in JoinTeamDetails struct
  * Added the EventTypeArg union
  * Update comment for retain_team_shares arg of MembersRemoveArg
  * Fix bug in constructor for OAuth object (expires_in -> expiration)
  * Remove oauth examples from code and redirect to examples folder
  * Bug Fix to add timeout parameter to Refresh Token calls
  * added a new route property is_cloud_doc_auth indicating whether the endpoint is a Dropbox cloud docs endpoint which takes cloud docs auth token.
  * lock_file_batch, unlock_file_batch and get_file_lock_batch are no longer preview routes
  * Update query description on SearchArg Struct, SearchV2Arg Struct
  * Update move:2 and move_batch:2 route descirption
  * Deleted deprecated routes legal_holds/export_policy and legal_holds/export_policy_job_status/check
  * Added AccountState union
  * Added AccountLockOrUnlockedType struct
  * Added AccountLockOrUnlockedDetails struct
  * Added MemberSendInvitePolicy union
  * Added MemberSendInvitePolicyChangedType struct
  * Added MemberSendInvitePolicyChangedDetails struct
  * Added a new tag first_party_token_exchange to LoginMethod union
  * Added new tags account_lock_or_unlocked_details and member_send_invite_policy_changed_details to EventDetails union
  * Added new tags account_lock_or_unlocked and member_send_invite_policy_changed to EventType union
  * Added a new field file_size to FileOrFolderLogInfo and FileLogInfo struct
  * Added a new field file_count to FolderLogInfo struct
  * Add NoExpirationLinkGenCreateReportDetails, NoExpirationLinkGenReportFailedDetails, NoPasswordLinkGenCreateReportDetails, NoPasswordLinkGenReportFailedDetails, NoPasswordLinkViewCreateReportDetails, NoPasswordLinkViewReportFailedDetails, OutdatedLinkViewCreateReportDetails, OutdatedLnkViewReportFailedDetails structs to the EventDetails union
  * Add NoExpirationLinkGenCreateReportType, NoExpirationLinkGenReportFailedType, NoPasswordLinkGenCreateReportType, NoPasswordLinkGenReportFailedType, NoPasswordLinkViewCreateReportType, NoPasswordLinkViewReportFailedType, OutdatedLinkViewCreateReportType, OutdatedLinkViewReportFailedType structs to the EventType union
  * Add get_content, get_metadata, rename, unlock, and lock routes
  * Add corresponding args, results, and errors
  * Update AddPropertiesArg description
  * Add duplicate_property_groups to InvalidPropertyGroupError Union
  * Update property_groups description on AddPropertiesError Union
  * Update SharedLinkSettings example
  * Update auth type string patterns
  * Update host string patterns
  * Update style string patterns
  * Update select_admin_mode string patterns
  * Add team_exceeded_legal_hold_quota to LegalHoldsPolicyCreateError union
  * Change LegalHoldsListHeldRevisionsError and LegalHoldsPolicyReleaseError to extend LegalHoldsError
  * Remove is_preview from route add, resend_verification_emails, and delete
  * Add support for PKCE
  * Add support for Short-Lived Tokens
  * Add support for Scopes
  * These features are all in beta, please contact Dropbox support if you are interested in these features
  * Update Requirements.txt
  * Add Github action to auto-publish to pypi
  * DropboxOAuth2Flow consumer_secret parameter moved to end of constructor as it became optional with support of PKCE
  * Assertions in constructors have been mapped to their BadInputException
* Fri Apr  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 9.5.0
  * Add optional lockholder_account_id to FileLockMetadata struct
  * Add optional invalid_argument to SearchError union
  * Add get_thumbnail:2 route
  * Add add_creator_as_owner to GroupCreateArg struct
  * Add exporting to LegalHoldStatus union
  * Add MembersInfo struct
  * Add team_invite_details to ActionDetails union
  * Add optional indicators to JoinTeamDetails struct
  * Add optional shared_content_link to SharedLinkSettings* structs
  * Add many functionalities to EventType and EventDetails unions
  * Add InviteMethod union
  * Add LockStatus union
  * Add RewindPolicy union
  * Add FileLockingValue union
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 9.4.0
  * auth Namespace:
    Added missing_scope into AuthError.
  * file_requests namespace:
    Added list and list/continue endpoints.
    Added count endpoint.
    Added delete and delete_all_closed endpoints.
  * files namespace:
    Added unsupported_file to DownloadError.
    Added upper bound 9999 to start field in SearchArg.
    Added unsupported_content_type to LookupError.
    Added cant_move_shared_folder to RelocationError.
    Added email_not_verified and unsupported_file to GetTemporaryLinkError.
    Added ExportInfo struct.
    Added fields (is_downloadable, export_info) to FileMetadata.
    Added include_non_downloadable_files to ListFolderArg.
    Added ExportMetadata, ExportArg, Export Result Structs.
    Added ExportError union.
    Added /export route.
  * seen_state namespace:
    Added mobile_ios, mobile_android and api into PlatformType.
    Deprecated mobile in PlatformType.
  * sharing namespace:
    Updated shared_link_already_exists under CreateSharedLinkWithSettingsError from void to SharedLinkAlreadyExistsMetadata.
    Updated docstrings for LinkPermissions
    Added banned_member to AddFolderMemberError.
    Added password field to LinkAudience.
    Added effective_audience and link_access_level fields to LinkPermissions struct.
    Added audience and access fields to SharedLinkSettings struct.
    Added LinkAccessLevel and RequestedLinkAccessLevel union.
    Added create_view_link and create_edit_link fields to FileAction union.
  * team namespace:
    Added profile_photo_url and suspended_on into MemberProfile.
  * team_log namespace:
    Added various new types.
  * team_policies namespace:
    Added TwoStepVerificationState union.
  * team_reports namespace:
    Added TemporaryFailureReason union.
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v9.3.0
